==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/SplineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SplineSeriesBaseDescriptionMetadata } from "./SplineSeriesBaseDescriptionMetadata";
import { SplineSeriesDescription } from "./SplineSeriesDescription";
/**
 * @hidden
 */
export let SplineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class SplineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (SplineSeriesDescriptionMetadata.a == null) {
                SplineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SplineSeriesDescriptionMetadata.c(SplineSeriesDescriptionMetadata.a);
            }
            if (a.j(SplineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.y(SplineSeriesDescriptionMetadata.a);
        }
        static c(a) {
            SplineSeriesBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            SplineSeriesDescriptionMetadata.b(a);
            a.aa("SplineSeries", () => new SplineSeriesDescription());
            a.z("SplineSeries", SplineSeriesDescriptionMetadata.a);
        }
    }
    SplineSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(SplineSeriesDescriptionMetadata, 'SplineSeriesDescriptionMetadata');
    SplineSeriesDescriptionMetadata.a = null;
    return SplineSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/SplineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SplineSeriesBaseDescriptionMetadata } from "./SplineSeriesBaseDescriptionMetadata";
import { SplineSeriesDescription } from "./SplineSeriesDescription";
/**
 * @hidden
 */
export let SplineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class SplineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (SplineSeriesDescriptionMetadata.a == null) {
                SplineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SplineSeriesDescriptionMetadata.c(SplineSeriesDescriptionMetadata.a);
            }
            if (a.k(SplineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(SplineSeriesDescriptionMetadata.a);
        }
        static c(a) {
            SplineSeriesBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            SplineSeriesDescriptionMetadata.b(a);
            a.ac("SplineSeries", () => new SplineSeriesDescription());
            a.ab("SplineSeries", SplineSeriesDescriptionMetadata.a);
        }
    }
    SplineSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(SplineSeriesDescriptionMetadata, 'SplineSeriesDescriptionMetadata');
    SplineSeriesDescriptionMetadata.a = null;
    return SplineSeriesDescriptionMetadata;
})();
